# TEI commands

## serialize person from collection

`python manage.py persons_to_tei --collection=5  --settings=apis.settings.local_pmb`

## serialize all person full

`python manage.py persons_to_tei --full=true --settings=apis.settings.local_pmb`